/**
 * MCS Media Computer Software
 * Copyright 2018 by Wilfried Klaas
 * Project: SPSEmulator
 * File: AbstractMnemonic.java
 * EMail: W.Klaas@gmx.de
 * Created: 25.11.2018 wklaa_000
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>
 */
package de.mcs.tools.sps.mnemonic;

import org.apache.commons.lang3.StringUtils;

/**
 * @author wklaa_000
 *
 */
public abstract class AbstractMnemonic implements Mnemonic {

  private String srcLine;
  private String name;
  private String argument;
  private int lineNumber;

  public static String getName(String line) {
    String srcLine = line.trim();
    if (srcLine.indexOf(" ") >= 0) {
      String[] values = srcLine.split(" ");
      return values[0].toUpperCase();
    }
    return srcLine.toUpperCase();
  }

  AbstractMnemonic(String line) {
    this.srcLine = line.trim();
    this.name = srcLine;
    if (srcLine.indexOf(" ") >= 0) {
      String[] values = srcLine.split(" ");
      this.name = values[0].toUpperCase();
      if (values.length > 1) {
        this.argument = values[1];
      }
    }
  }

  @Override
  public String toString() {
    return String.format("%s %s", name, StringUtils.isEmpty(argument) ? "" : argument);
  }

  /**
   * @return the name
   */
  @Override
  public String getName() {
    return name;
  }

  /**
   * @return the argument
   */
  @Override
  public String getArgument() {
    return argument;
  }

  public abstract int getByte();

  @Override
  public boolean isUsingPage() {
    return false;
  }

  @Override
  public void setLineNumber(int lineNumber) {
    this.lineNumber = lineNumber;
  }
}
